# Contributing

## Use tox for common tasks

See the `tox.ini` file for a list of
common tasks that help with development.

Generally, to verify your code is ready for a PR, the following commands must pass:

```
tox -e test
tox -e lint
```
